Perturbs a set of mixing proportions by first scaling the
mixing proporitons, then taking the logit of the scaled values,
perturbing them, and inverting back to produce a set of
new mixing proportions.
Usage
lambda.pert(lambda, pert)
Arguments
lambda
A vector of length k giving the mixing proportions which
are to be perturbed.
pert
A vector (likely of length k-1) for which to perturb lambda.
If the length is less than k-1, then values of the vector are recycled. If length
is greater than k-1, then only the first k-1 values are used.
Value
lambda.pert returns new lambda values perturbed by pert.